<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Montana";
    var qsoPartyUrl = "http://ws7n.net/7QP";
    var overlayUrl = "http://www.no5w.com/OverlayMontanaRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Beaverhead", "mtbea");
  countySelection.options[1] = new Option("BigHornMT", "mtbig");
  countySelection.options[2] = new Option("BlaineMT", "mtbla");
  countySelection.options[3] = new Option("Broadwater", "mtbro");
  countySelection.options[4] = new Option("CarbonMT", "mtcrb");
  countySelection.options[5] = new Option("Carter", "mtcrt");
  countySelection.options[6] = new Option("Cascade", "mtcas");
  countySelection.options[7] = new Option("Chouteau", "mtcho");
  countySelection.options[8] = new Option("CusterMT", "mtcus");
  countySelection.options[9] = new Option("Daniels", "mtdan");
  countySelection.options[10] = new Option("Dawson", "mtdaw");
  countySelection.options[11] = new Option("DeerLodge", "mtdee");
  countySelection.options[12] = new Option("Fallon", "mtfal");
  countySelection.options[13] = new Option("Fergus", "mtfer");
  countySelection.options[14] = new Option("Flathead", "mtfla");
  countySelection.options[15] = new Option("Gallatin", "mtgal");
  countySelection.options[16] = new Option("GarfieldMT", "mtgar");
  countySelection.options[17] = new Option("Glacier", "mtgla");
  countySelection.options[18] = new Option("GoldenValleyMT", "mtgol");
  countySelection.options[19] = new Option("Granite", "mtgra");
  countySelection.options[20] = new Option("Hill", "mthil");
  countySelection.options[21] = new Option("JeffersonMT", "mtjef");
  countySelection.options[22] = new Option("JudithBasin", "mtjud");
  countySelection.options[23] = new Option("LakeMT", "mtlak");
  countySelection.options[24] = new Option("LewisandClark", "mtlew");
  countySelection.options[25] = new Option("Liberty", "mtlib");
  countySelection.options[26] = new Option("LincolnMT", "mtlin");
  countySelection.options[27] = new Option("MadisonMT", "mtmad");
  countySelection.options[28] = new Option("McCone", "mtmcc");
  countySelection.options[29] = new Option("Meagher", "mtmea");
  countySelection.options[30] = new Option("MineralMT", "mtmin");
  countySelection.options[31] = new Option("Missoula", "mtmis");
  countySelection.options[32] = new Option("Musselshell", "mtmus");
  countySelection.options[33] = new Option("ParkMT", "mtpar");
  countySelection.options[34] = new Option("Petroleum", "mtpet");
  countySelection.options[35] = new Option("Phillips", "mtphi");
  countySelection.options[36] = new Option("Pondera", "mtpon");
  countySelection.options[37] = new Option("PowderRiver", "mtpwd");
  countySelection.options[38] = new Option("Powell", "mtpwl");
  countySelection.options[39] = new Option("Prairie", "mtpra");
  countySelection.options[40] = new Option("Ravalli", "mtrav");
  countySelection.options[41] = new Option("Richland", "mtric");
  countySelection.options[42] = new Option("Roosevelt", "mtroo");
  countySelection.options[43] = new Option("Rosebud", "mtros");
  countySelection.options[44] = new Option("Sanders", "mtsan");
  countySelection.options[45] = new Option("SheridanMT", "mtshe");
  countySelection.options[46] = new Option("SilverBow", "mtsil");
  countySelection.options[47] = new Option("Stillwater", "mtsti");
  countySelection.options[48] = new Option("SweetGrass", "mtswe");
  countySelection.options[49] = new Option("TetonMT", "mttet");
  countySelection.options[50] = new Option("Toole", "mttoo");
  countySelection.options[51] = new Option("Treasure", "mttre");
  countySelection.options[52] = new Option("ValleyMT", "mtval");
  countySelection.options[53] = new Option("Wheatland", "mtwhe");
  countySelection.options[54] = new Option("Wibaux", "mtwib");
  countySelection.options[55] = new Option("Yellowstone", "mtyel");
  addMarker(45.14980000, -112.70500000, "Beaverhead", "mtbea");
  addMarker(45.51870000, -107.48200000, "BigHornMT", "mtbig");
  addMarker(48.36060000, -108.89400000, "BlaineMT", "mtbla");
  addMarker(46.30770000, -111.42200000, "Broadwater", "mtbro");
  addMarker(45.31910000, -108.94800000, "CarbonMT", "mtcrb");
  addMarker(45.56710000, -104.53900000, "Carter", "mtcrt");
  addMarker(47.25860000, -111.34200000, "Cascade", "mtcas");
  addMarker(47.86100000, -110.47100000, "Chouteau", "mtcho");
  addMarker(46.32400000, -105.46200000, "CusterMT", "mtcus");
  addMarker(48.78140000, -105.56300000, "Daniels", "mtdan");
  addMarker(47.32580000, -104.85600000, "Dawson", "mtdaw");
  addMarker(46.01240000, -113.03800000, "DeerLodge", "mtdee");
  addMarker(46.28350000, -104.47500000, "Fallon", "mtfal");
  addMarker(47.24850000, -109.26300000, "Fergus", "mtfer");
  addMarker(48.29890000, -113.95000000, "Flathead", "mtfla");
  addMarker(45.33370000, -111.29500000, "Gallatin", "mtgal");
  addMarker(47.41410000, -107.02700000, "GarfieldMT", "mtgar");
  addMarker(48.65410000, -113.12600000, "Glacier", "mtgla");
  addMarker(46.39800000, -109.21600000, "GoldenValleyMT", "mtgol");
  addMarker(46.38540000, -113.45700000, "Granite", "mtgra");
  addMarker(48.56660000, -110.11000000, "Hill", "mthil");
  addMarker(46.15840000, -112.12900000, "JeffersonMT", "mtjef");
  addMarker(47.04460000, -110.26700000, "JudithBasin", "mtjud");
  addMarker(47.59500000, -114.10200000, "LakeMT", "mtlak");
  addMarker(47.18420000, -112.33000000, "LewisandClark", "mtlew");
  addMarker(48.56530000, -111.07600000, "Liberty", "mtlib");
  addMarker(48.44570000, -115.33100000, "LincolnMT", "mtlin");
  addMarker(45.28360000, -112.02700000, "MadisonMT", "mtmad");
  addMarker(47.59530000, -105.81200000, "McCone", "mtmcc");
  addMarker(46.63620000, -110.96600000, "Meagher", "mtmea");
  addMarker(47.09690000, -115.07500000, "MineralMT", "mtmin");
  addMarker(47.11610000, -114.05000000, "Missoula", "mtmis");
  addMarker(46.44420000, -108.39500000, "Musselshell", "mtmus");
  addMarker(45.59240000, -110.42300000, "ParkMT", "mtpar");
  addMarker(47.17360000, -108.28100000, "Petroleum", "mtpet");
  addMarker(48.22480000, -108.03500000, "Phillips", "mtphi");
  addMarker(48.23420000, -112.37900000, "Pondera", "mtpon");
  addMarker(45.39110000, -105.63100000, "PowderRiver", "mtpwd");
  addMarker(46.93300000, -112.88000000, "Powell", "mtpwl");
  addMarker(46.86110000, -105.34500000, "Prairie", "mtpra");
  addMarker(46.06020000, -114.04100000, "Ravalli", "mtrav");
  addMarker(47.75210000, -104.63800000, "Richland", "mtric");
  addMarker(48.28010000, -104.94400000, "Roosevelt", "mtroo");
  addMarker(46.01800000, -106.99200000, "Rosebud", "mtros");
  addMarker(47.69220000, -115.11800000, "Sanders", "mtsan");
  addMarker(48.69450000, -104.55200000, "SheridanMT", "mtshe");
  addMarker(45.90530000, -112.63800000, "SilverBow", "mtsil");
  addMarker(45.64970000, -109.45300000, "Stillwater", "mtsti");
  addMarker(45.69630000, -109.85500000, "SweetGrass", "mtswe");
  addMarker(47.81720000, -112.21300000, "TetonMT", "mttet");
  addMarker(48.60910000, -111.73200000, "Toole", "mttoo");
  addMarker(46.17620000, -107.33900000, "Treasure", "mttre");
  addMarker(48.33020000, -106.61000000, "ValleyMT", "mtval");
  addMarker(46.48570000, -109.83500000, "Wheatland", "mtwhe");
  addMarker(47.01950000, -104.32600000, "Wibaux", "mtwib");
  addMarker(45.97830000, -108.19500000, "Yellowstone", "mtyel");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

